@@ -24,8 +24,8 @@ class Profitdataframe(pd.DataFrame):
     此包构建的目的是为了在EDA过程中自动化处理一些问题
     目前写了几个方法：
     q_info 方法是对原df.info()的重构。返回一个DataFrame,包含原表的列名、各列总计数目、非空、空、空率、字段类型、前五预览
-    q_view 方法将原本pd.plotting.scatter_matrix(df) 缩写,即查看各列间的多重共线性
-    q_tips 方法塞入了一些常用的命令，方便复制修改（好吧我承认是为了考试写的这个方法）
+    q_view 方法将原本pd.plotting.scatter_matrix(df) 缩写,即查看各列间的相关性
+    q_tips 方法塞入了一些常用的命令，方便复制修改
     '''
     
     def q_info(self):
@@ -58,24 +58,24 @@ class Profitdataframe(pd.DataFrame):
     def q_view(self):
         pd.plotting.scatter_matrix(self)
 
-    def sta_describe(self,y_colname=None):
-		for i in self.columns:
-			if self[i].dtype != 'object':
-				plt.figure(10,6)
-				sns.kdeplot(self[i],legend = True)
-				if y_colname:
-					plt.figure(10,6)
-					sns.joinplot(i,y_colname,data=self,kind='reg')
-			else:
-				plt.figure(10,6)
-				sns.barplot(self[i])
+    def sta_describe(self,y_colname=None): 
+        for i in self.columns:
+            if self[i].dtype != 'object': 
+                plt.figure(figsize = (10,6))
+                sns.kdeplot(self[i],legend = True)
+                if y_colname:
+                    plt.figure(figsize = (10,6))
+                    sns.joinplot(i,y_colname,data=self,kind='reg')
+            else:
+                plt.figure(figsize = (10,6))
+                sns.barplot(self[i])
         
     def q_tips(self,code = 0):
         if code == 0:
             print(r'code menu is online','code=0 means find this menu',
                  r'code = 1 means find shell for active-out',
                  r'code = 2 means find shell for wrongs in plot',
-                 r'code =4 find what in this model'
+                 r'code = 3 find what in this model'
                  ,sep = '\n')
         if code == 1 :
             print(r"from IPython.core.interactiveshell import InteractiveShell",
@@ -88,13 +88,13 @@ class Profitdataframe(pd.DataFrame):
                   r"sns.set_style('whitegrid',{'font.sans-serif':['simhei','Arial']})"
             ,sep = '/n')
         if code == 3:
-        	print(r".q_info() show the infos of dataframe",
-        		r".q_view() show the scatter_matrix of dataframe",
-        		r".q_tips(code = 0) show the menu of this module",
-        		r"gap_statistic(X,B = 10,K=range(1,11)) find the best K by gap_statistic in KMeanns",
-        		r"dup_corr(X,nodatetime) show the corr of duplications in X . nodatetime means datatimeindex not in dups",
-        		r".sta_describe(y_colname=None) show the kde and joinplot of numberic and bar of object"
-        		,sep = '/n')
+            print(r".q_info() show the infos of dataframe",
+                r".q_view() show the scatter_matrix of dataframe",
+                r".q_tips(code = 0) show the menu of this module",
+                r"gap_statistic(X,B = 10,K=range(1,11)) find the best K by gap_statistic in KMeanns",
+                r"dup_corr(X,nodatetime) show the corr of duplications in X . nodatetime means datatimeindex not in dups",
+                r".sta_describe(y_colname=None) show the kde and joinplot of numberic and bar of object"
+                ,sep = '\r\n')
 
 
 def short_pair_wise_D(each_cluster):
@@ -111,7 +111,7 @@ def compute_Wk(data,classfication_result):
     return Wk
 
 def gap_statistic(X,B=10,K= range(1,11),N_init=10):
-	'使用区间间隔统计方法寻找最优K值得主函数'
+    """使用区间间隔统计方法寻找最优K值得主函数"""
     X = np.array(X)
     shapes = X.shape
     tops = X.max(axis = 0)
@@ -148,17 +148,17 @@ def gap_statistic(X,B=10,K= range(1,11),N_init=10):
     plt.show()
 
 def dup_corr(x,nodatetime = True):
-	"""注意，这里只判断dtype为object的重复值情况，因为如int/period/float重复值是没啥意义的"""
-	tempdf = pd.DataFrame()
-	for i in x.columns:
-		if nodatetime:
-			if x.loc[:,i].dtype == 'object':
-				tempdf[i] = x.loc[:,i].duplicated()
-		else:
-			if (x.loc[:,i].dtype == 'object') or (x.loc[:,i].dtype == 'DatetimeIndex'):
-				tempdf[i] = x.loc[:,i].duplicated()
-	plt.figure(figuresize =(10,10))
-	sns.heatmap(tempdf.corr(),annot = True)
+    """注意，这里只判断dtype为object的重复值情况，因为如int/period/float重复值是没啥意义的"""
+    tempdf = pd.DataFrame()
+    for i in x.columns:
+        if nodatetime:
+            if x.loc[:,i].dtype == 'object':
+                tempdf[i] = x.loc[:,i].duplicated()
+        else:
+            if (x.loc[:,i].dtype == 'object') or (x.loc[:,i].dtype == 'DatetimeIndex'):
+                tempdf[i] = x.loc[:,i].duplicated()
+    plt.figure(figsize =(10,10))
+    sns.heatmap(tempdf.corr(),annot = True)
 
 
 
